/**
 * @file	tempsens.h
 * @author	Robert Steigemann
 * @date	15 January 2017
 * @brief	Measurement library for temperature sensor
 *
 * @license creative commons license CC BY-NC 4.0 http://creativecommons.org/licenses/by-nc/4.0/
 */

#ifndef TEMPSENS_H_
#define TEMPSENS_H_

/* Define exact exact resistor values here to improve accuracy. */
#define TEMPSENS_R5	10000L		//  10 kOhm		// old 2.12 schematic value was 42967L (43 kOhm)
#define TEMPSENS_R6   390L		// 390  Ohm		// old 2.12 schematic value was  1790L (1.8 kOhm)
#define TEMPSENS_R7	  820L      // 820  Ohm		// old 2.12 schematic value was  3530L (3.6 kOhm)
#define TEMPSENS_R8	  559L		// 560  Ohm

#define TEMPSENS_LP_SIZE 50		// low pass size


typedef enum tempsensState
{
	AVCC_OUT_OF_RANGE,			// problem with ADC
	TOOL_DISCONNECTED,			// soldering iron not connected
	OK							// measurement o.k.
} tempsensState_t;


// List of all available tools
typedef enum solderType
{
	WELLER_WP80,				// Weller WP80 soldering iron
	WELLER_WSP80,				// Weller WSP80 soldering iron
	TOOL_LAST
} solderType_t;


/**
 * @brief Initializes the ADC, call once after boot
 */ 
void tempsens_init(void);

/**
 * @brief Calculates the mean temperature from buffer
 *
 * @param solderTool The tool to calculate the temperature for
 * @return The temperature in degree centigrade
 */ 
float tempsens_get(solderType_t solderTool);

/**
 * @brief Takes a measure and put it in internal buffer with TEMPSENS_LP_SIZE
 *
 * @return The status of the measurement
 */ 
tempsensState_t tempsens_measure(void);

#endif /* TEMPSENS_H_ */